@@ -22,6 +22,7 @@ package soundutils
 import (
 	"encoding/json"
 	"io/ioutil"
+	"os"
 )
 
 const (
@@ -48,12 +49,20 @@ func GetShutdownSoundConfig() (*ShutdownSoundConfig, error) {
 	return &v, nil
 }
 
-func SetShutdownSoundConfig(v *ShutdownSoundConfig) error {
+func SetShutdownSoundConfig(v *ShutdownSoundConfig) (err error) {
+	if !v.CanPlay {
+		// 当不需要播放关机音效时，删除配置文件。
+		err = os.Remove(shutdownSoundFile)
+		if err != nil && os.IsNotExist(err) {
+			err = nil
+		}
+		return
+	}
 	data, err := json.Marshal(v)
 	if err != nil {
-		return err
+		return
 	}
 
 	err = ioutil.WriteFile(shutdownSoundFile, data, 0644)
-	return err
+	return
 }
